==> jupyterlite_ai-0.5.0.tar.gz: jupyterlite_ai-0.5.0/src/default-providers/OpenAI/completer.ts <==
import {
  CompletionHandler,
  IInlineCompletionContext
} from '@jupyterlab/completer';
import { BaseChatModel } from '@langchain/core/language_models/chat_models';
import { AIMessage, SystemMessage } from '@langchain/core/messages';
import { ChatOpenAI } from '@langchain/openai';

import { BaseCompleter, IBaseCompleter } from '../../base-completer';
import { COMPLETION_SYSTEM_PROMPT } from '../../provider';

export class OpenAICompleter implements IBaseCompleter {
  constructor(options: BaseCompleter.IOptions) {
    this._openAIProvider = new ChatOpenAI({ ...options.settings });
  }

  get provider(): BaseChatModel {
    return this._openAIProvider;
  }

  /**
   * Getter and setter for the initial prompt.
   */
  get prompt(): string {
    return this._prompt;
  }
  set prompt(value: string) {
    this._prompt = value;
  }

  async fetch(
    request: CompletionHandler.IRequest,
    context: IInlineCompletionContext
  ) {
    const { text, offset: cursorOffset } = request;
    const prompt = text.slice(0, cursorOffset);

    const messages = [new SystemMessage(this._prompt), new AIMessage(prompt)];

    try {
      const response = await this._openAIProvider.invoke(messages);
      const items = [];
      if (typeof response.content === 'string') {
        items.push({
          insertText: response.content
        });
      } else {
        response.content.forEach(content => {
          if (content.type !== 'text') {
            return;
          }
          items.push({
            insertText: content.text,
            filterText: prompt.substring(prompt.length)
          });
        });
      }
      return { items };
    } catch (error) {
      console.error('Error fetching completions', error);
      return { items: [] };
    }
  }

  private _openAIProvider: ChatOpenAI;
  private _prompt: string = COMPLETION_SYSTEM_PROMPT;
}

==> jupyterlite_ai-0.6.2.tar.gz: jupyterlite_ai-0.6.2/src/default-providers/OpenAI/completer.ts <==
import {
  CompletionHandler,
  IInlineCompletionContext
} from '@jupyterlab/completer';
import { BaseChatModel } from '@langchain/core/language_models/chat_models';
import { AIMessage, SystemMessage } from '@langchain/core/messages';
import { ChatOpenAI } from '@langchain/openai';

import { BaseCompleter, IBaseCompleter } from '../../base-completer';
import { COMPLETION_SYSTEM_PROMPT } from '../../provider';

export class OpenAICompleter implements IBaseCompleter {
  constructor(options: BaseCompleter.IOptions) {
    this._completer = new ChatOpenAI({ ...options.settings });
  }

  get completer(): BaseChatModel {
    return this._completer;
  }

  /**
   * Getter and setter for the initial prompt.
   */
  get prompt(): string {
    return this._prompt;
  }
  set prompt(value: string) {
    this._prompt = value;
  }

  async fetch(
    request: CompletionHandler.IRequest,
    context: IInlineCompletionContext
  ) {
    const { text, offset: cursorOffset } = request;
    const prompt = text.slice(0, cursorOffset);

    const messages = [new SystemMessage(this._prompt), new AIMessage(prompt)];

    try {
      const response = await this._completer.invoke(messages);
      const items = [];
      if (typeof response.content === 'string') {
        items.push({
          insertText: response.content
        });
      } else {
        response.content.forEach(content => {
          if (content.type !== 'text') {
            return;
          }
          items.push({
            insertText: content.text,
            filterText: prompt.substring(prompt.length)
          });
        });
      }
      return { items };
    } catch (error) {
      console.error('Error fetching completions', error);
      return { items: [] };
    }
  }

  private _completer: ChatOpenAI;
  private _prompt: string = COMPLETION_SYSTEM_PROMPT;
}
